@@ -80,8 +80,8 @@ stringprep_apply_table_to_string (long *ucs4,
 	return STRINGPREP_TOO_SMALL_BUFFER;
 
       memmove (&ucs4[pos + maplen], &ucs4[pos + 1],
-	       *ucs4len * sizeof (uint32_t) - (&ucs4[pos + 1] - ucs4));
-      memcpy (&ucs4[pos], table[i].map, sizeof (uint32_t) * maplen);
+	       *ucs4len * sizeof (long) - (&ucs4[pos + 1] - ucs4));
+      memcpy (&ucs4[pos], table[i].map, sizeof (long) * maplen);
       *ucs4len = *ucs4len - 1 + maplen;
     }
 
@@ -203,7 +203,10 @@ stringprep (char *in, int maxlen, int flags, Stringprep_profile * profile)
 		  done_prohibited = 1;
 		  if (stringprep_find_string_in_table
 		      (ucs4, ucs4len, NULL, profile[j].table) != -1)
-		    return STRINGPREP_BIDI_CONTAINS_PROHIBITED;
+		    {
+		      rc = STRINGPREP_BIDI_CONTAINS_PROHIBITED;
+		      goto done;
+		    }
 		}
 	      else if (profile[j].operation == STRINGPREP_BIDI_RAL_TABLE)
 		{
@@ -268,7 +271,7 @@ stringprep (char *in, int maxlen, int flags, Stringprep_profile * profile)
       goto done;
     }
 
-  strcpy (in, p);
+  strcpy (in, p);		/* flawfinder: ignore */
 
   rc = STRINGPREP_OK;
 
